@@ -26,8 +26,8 @@ import datetime
 from typing import AsyncIterator, TypeVar, Awaitable, Any, Optional, Callable, Union, List, TYPE_CHECKING
 
 from .error import NoMoreItems
-from .utils import maybe_coroutine
 from .object import Object
+from .utils import maybe_coroutine
 
 if TYPE_CHECKING:
     from .types.guild import (
@@ -36,11 +36,7 @@ if TYPE_CHECKING:
     from .types.message import (
         Message as MessagePayload,
     )
-    from .types.user import (
-        PartialUser as PartialUserPayload,
-    )
     from .member import Member
-    from .user import User
     from .message import Message
     from .guild import Guild
 
@@ -353,8 +349,9 @@ class HistoryIterator(_AsyncIterator['Message']):
 
             self._retrieve_messages = self._retrieve_messages_around_strategy  # type: ignore
             if self.before and self.after:
-                self._filter = lambda m:\
-                    self.timestamp(self.after) < self.timestamp(m['timestamp']) < self.timestamp(self.before)  # type: ignore
+                self._filter = lambda m: \
+                    self.timestamp(self.after) < self.timestamp(m['timestamp']) < self.timestamp(
+                        self.before)  # type: ignore
             elif self.before:
                 self._filter = lambda m: self.timestamp(m['timestamp']) < self.timestamp(self.before)  # type: ignore
             elif self.after:
@@ -363,7 +360,8 @@ class HistoryIterator(_AsyncIterator['Message']):
             if self.reverse:
                 self._retrieve_messages = self._retrieve_messages_after_strategy  # type: ignore
                 if self.before:
-                    self._filter = lambda m: self.timestamp(m['timestamp']) < self.timestamp(self.before)  # type: ignore
+                    self._filter = lambda m: self.timestamp(m['timestamp']) < self.timestamp(
+                        self.before)  # type: ignore
             else:
                 self._retrieve_messages = self._retrieve_messages_before_strategy  # type: ignore
                 if self.after and self.after != 0:
