@@ -482,6 +482,8 @@ class Message(Hashable):
         发送消息的 :class:`TextChannel`。
     mention_everyone: :class:`bool`
         指定消息是否提及所有人。
+    reactions: List[:class:`Reaction`]
+        消息的回应/反应列表
 
         .. note::
 
@@ -609,10 +611,7 @@ class Message(Hashable):
                 continue
 
     def __repr__(self) -> str:
-        name = self.__class__.__name__
-        return (
-            f'<{name} id={self.id} channel={self.channel!r} author={self.author!r}>'
-        )
+        return f'<{self.__class__.__name__} id={self.id} channel={self.channel!r} author={self.author!r}>'
 
     def _try_patch(self, data, key, transform=None) -> None:
         try:
